@@ -12,6 +12,7 @@ from tensorflow.keras.regularizers import l2
 
 from ...layers import DNN
 from ...layers import FFM as FFM_Layer
+from ...layers import CrossLayer as CrossNetwork
 from ...layers import Dice, Linear
 from ...layers.fm import FactorizationMachine
 
@@ -80,26 +81,6 @@ class AFM(Model):
         return outputs
 
 
-class FFM(Model):
-    def __init__(self, feature_columns, k, w_reg=1e-4, v_reg=1e-4):
-        """
-        FFM architecture
-        :param feature_columns:  a list containing dense and sparse column feature information
-        :param k: the latent vector
-        :param w_reg: the regularization coefficient of parameter w
-                :param field_reg_reg: the regularization coefficient of parameter v
-        """
-        super(FFM, self).__init__()
-        self.dense_feature_columns, self.sparse_feature_columns = feature_columns
-        self.ffm = FFM_Layer(self.dense_feature_columns, self.sparse_feature_columns,
-                             k, w_reg, v_reg)
-
-    def call(self, inputs, **kwargs):
-        result_ffm = self.ffm(inputs)
-        outputs = tf.nn.sigmoid(result_ffm)
-
-        return outputs
-
 
 class NFM(Model):
     def __init__(self, feature_columns, hidden_units, dnn_dropout=0., activation='relu', bn_use=True, embed_reg=1e-4):
@@ -405,52 +386,6 @@ class WideDeep(Model):
         return outputs
 
 
-class CrossNetwork(Layer):
-    """
-    Cross Network
-    """
-
-    def __init__(self, layer_num, reg_w=1e-4, reg_b=1e-4):
-        """
-        :param layer_num: A scalar. The depth of cross network
-        :param reg_w: A scalar. The regularizer of w
-        :param reg_b: A scalar. The regularizer of b
-        """
-        super(CrossNetwork, self).__init__()
-        self.layer_num = layer_num
-        self.reg_w = reg_w
-        self.reg_b = reg_b
-
-    def build(self, input_shape):
-        dim = int(input_shape[-1])
-        self.cross_weights = [
-            self.add_weight(name='w_' + str(i),
-                            shape=(dim, 1),
-                            initializer='random_uniform',
-                            regularizer=l2(self.reg_w),
-                            trainable=True
-                            )
-            for i in range(self.layer_num)]
-        self.cross_bias = [
-            self.add_weight(name='b_' + str(i),
-                            shape=(dim, 1),
-                            initializer='random_uniform',
-                            regularizer=l2(self.reg_b),
-                            trainable=True
-                            )
-            for i in range(self.layer_num)]
-
-    def call(self, inputs, **kwargs):
-        x_0 = tf.expand_dims(inputs, axis=2)  # (None, dim, 1)
-        x_l = x_0  # (None, dim, 1)
-        for i in range(self.layer_num):
-            x_l1 = tf.tensordot(x_l, self.cross_weights[i], axes=[
-                                1, 0])  # (None, dim, dim)
-            x_l = tf.matmul(x_0, x_l1) + \
-                self.cross_bias[i] + x_l  # (None, dim, 1)
-        x_l = tf.squeeze(x_l, axis=2)  # (None, dim)
-        return x_l
-
 
 class DCN(Model):
     def __init__(self, feature_columns, hidden_units, activation='relu',
